@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/builtin-sockets.c,v 1.16 2004/12/11 06:02:23 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/builtin-sockets.c,v 1.17 2005/07/09 05:46:54 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -223,6 +223,13 @@ do_Socket_connect (Value s, Value host, Value port)
 	int n, err;
 	flags |= O_NONBLOCK;
 	fcntl (s->file.fd, F_SETFL, flags);
+#ifdef SO_BROADCAST
+	{
+	    int one = 1;
+	    setsockopt (s->file.fd, SOL_SOCKET, SO_BROADCAST,
+			(char *) &one, sizeof (int));
+	}
+#endif
 	n = connect (s->file.fd, (struct sockaddr *) &addr, sizeof addr);
 	flags &= ~O_NONBLOCK;
 	fcntl (s->file.fd, F_SETFL, flags);
