@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/builtin-string.c,v 1.11 2004/06/08 09:30:53 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/builtin-string.c,v 1.12 2005/08/03 06:34:05 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -125,7 +125,7 @@ do_String_index (Value av, Value bv)
     i = 0;
     while (a < p)
     {
-	int c;
+	unsigned c;
 	a = StringNextChar (a, &c, &al);
 	i++;
     }
@@ -170,7 +170,7 @@ do_String_substr (Value av, Value bv, Value cv)
      */
     while (b > 0)
     {
-	int ch;
+	unsigned ch;
 	a = StringNextChar (a, &ch, &alen);
 	b--;
     }
@@ -181,7 +181,7 @@ do_String_substr (Value av, Value bv, Value cv)
     elen = alen;
     while (c > 0)
     {
-	int ch;
+	unsigned ch;
 	e = StringNextChar (e, &ch, &elen);
 	c--;
     }
