@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/file.c,v 1.67 2005/01/14 05:44:00 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/file.c,v 1.68 2005/08/03 06:34:05 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -1311,7 +1311,7 @@ FileStringWidth (char *string, long length, char format)
     else
     {
 	int	    width = 2;
-	int	    c;
+	unsigned    c;
 	while ((string = StringNextChar (string, &c, &length)))
 	{
 	    if (c < ' ' || '~' < c)
@@ -1345,7 +1345,7 @@ FilePutString (Value f, char *string, long length, char format)
 	FilePutsc (f, string, length);
     else
     {
-	int c;
+	unsigned c;
 	FileOutput (f, '"');
 	while ((string = StringNextChar (string, &c, &length))) 
 	{
