@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/rational.c,v 1.30 2005/06/05 01:03:42 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/rational.c,v 1.31 2005/08/03 06:34:05 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -752,7 +752,7 @@ RationalDecimalPrint (Value f, Value rv, char format, int base, int width, int p
     char	*initial = 0, *in;
     char	*repeat = 0, *re;
     char	*whole;
-    int		initial_width, repeat_width;
+    int		initial_width, repeat_width = 0;
     int		frac_width;
     int		rep_width, brace_width = 0, dot_width = 0;
     int		whole_width;
