@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/util.c,v 1.8 2004/02/27 03:50:16 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/util.c,v 1.9 2004/07/09 18:48:35 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -45,6 +45,9 @@ AllocateTemp (int size)
 
 #ifdef HAVE_VPRINTF
 
+#include	<sys/poll.h>
+#include	<errno.h>
+
 /*
  * Currently vfprintf() is required.  It would
  * be easy to do a _doprnt() version if necessary,
@@ -52,24 +55,67 @@ AllocateTemp (int size)
  * non-varargs versions of these.  Contributed code welcome.
  */
 
+static int
+wait_write (int fd, char *buf, int len)
+{
+    int	n;
+    int w = 0;
+
+    while (len)
+    {
+	n = write (fd, buf, len);
+	if (n < 0)
+	{
+	    if (errno == EINTR)
+	    {
+		struct pollfd   f;
+    
+		f.fd = fd;
+		f.events = POLLOUT;
+    
+		(void) poll (&f, 1, -1);
+	    }
+	    else
+	    {
+		if (w)
+		    return w;
+		return -1;
+	    }
+	}
+	else
+	{
+	    w += n;
+	    buf += n;
+	    len -= n;
+	}
+    }
+    return w;
+}
+
 void
 debug (char *format, ...)
 {
     va_list	ap;
+    char	buf[4096];
+    int		len;
 
     va_start (ap, format);
-    vfprintf (stderr, format, ap);
+    len = vsnprintf (buf, sizeof (buf), format, ap);
     va_end (ap);
+    wait_write (2, buf, len);
 }
 
 void
 panic (char *format, ...)
 {
     va_list	ap;
+    char	buf[4096];
+    int		len;
 
     va_start (ap, format);
-    vfprintf (stderr, format, ap);
+    len = vsnprintf (buf, sizeof (buf), format, ap);
     va_end (ap);
+    wait_write (2, buf, len);
     abort ();
 }
 
